package com.ruoyi.abuwx.mapper;

import java.util.List;

import com.ruoyi.abuwx.domain.CardCoupons;

/**
 * 卡券管理Mapper接口
 *
 * @author lujie
 * @date 2025-01-07
 */
public interface CardCouponsMapper {
    /**
     * 查询卡券管理
     *
     * @param id 卡券管理主键
     * @return 卡券管理
     */
    public CardCoupons selectCardCouponsById(Long id);

    /**
     * 查询卡券管理列表
     *
     * @param cardCoupons 卡券管理
     * @return 卡券管理集合
     */
    public List<CardCoupons> selectCardCouponsList(CardCoupons cardCoupons);

    /**
     * 新增卡券管理
     *
     * @param cardCoupons 卡券管理
     * @return 结果
     */
    public int insertCardCoupons(CardCoupons cardCoupons);

    /**
     * 修改卡券管理
     *
     * @param cardCoupons 卡券管理
     * @return 结果
     */
    public int updateCardCoupons(CardCoupons cardCoupons);

    /**
     * 删除卡券管理
     *
     * @param id 卡券管理主键
     * @return 结果
     */
    public int deleteCardCouponsById(Long id);

    /**
     * 批量删除卡券管理
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteCardCouponsByIds(Long[] ids);
}
